@@ -1,9 +1,9 @@
-"""Provides AJAX file upload functionality for FileFields and ImageFields with a simple widget replacement in the form."""
+"""This app provides a Backbone.js compatible REST API for your models. It follows the Django admin pattern of extending, overriding and registering; and provides an extendable class based view for customization."""
 
 from backbone.sites import BackboneSite
 
 
-VERSION = (0, 1, 0)
+VERSION = (0, 2, 0)
 
 __version__ = '.'.join(map(str, VERSION))
 
